//
//  HDBaseViewController.m
//  PortableTreasure
//
//  Created by HeDong on 14/12/14.
//  Copyright © 2014年 hedong. All rights reserved.
//

#import "HDBaseViewController.h"
#import "HDBaseModel.h"
#import "HDGroupModel.h"
#import "HDBaseTableViewCell.h"
#import "HDCanJumpModel.h"
#import "TestModel.h"
#import "HHTableViewCell.h"

@interface HDBaseViewController ()

@end

@implementation HDBaseViewController

- (void)viewDidLoad
{
    [super viewDidLoad];
    
    [self setUpSubviews];
}

- (void)setUpSubviews;
{
    UITableView *tableView = [[UITableView alloc] initWithFrame:self.view.bounds style:UITableViewStyleGrouped];
    
    tableView.delegate = self;
    tableView.dataSource = self;
    [self.view addSubview:tableView];
    self.baseTableView = tableView;
}

#pragma mark - 懒加载
- (NSArray *)groupsArr
{
    if (!_groupsArr)
    {
        _groupsArr = [NSArray array];
    }
    return _groupsArr;
}

- (HDGroupModel *)groupModel
{
    if (!_groupModel)
    {
        _groupModel = [[HDGroupModel alloc] init];
    }
    return _groupModel;
}

- (HDBaseModel *)baseModel
{
    if (!_baseModel)
    {
        _baseModel = [[HDBaseModel alloc] init];
    }
    return _baseModel;
}

#pragma mark - <UITableViewDelegate, UITableViewDataSource>
- (NSInteger)numberOfSectionsInTableView:(UITableView *)tableView
{
    return self.groupsArr.count;
}

- (NSInteger)tableView:(UITableView *)tableView numberOfRowsInSection:(NSInteger)section
{
    self.groupModel = self.groupsArr[section];
    return self.groupModel.baseModels.count;
}

- (UITableViewCell *)tableView:(UITableView *)tableView cellForRowAtIndexPath:(NSIndexPath *)indexPath
{
    self.groupModel = self.groupsArr[indexPath.section];
    self.baseModel = self.groupModel.baseModels[indexPath.row];
    
    if ([self.baseModel isKindOfClass:[TestModel class]])
    {
        TestModel *testModel = (TestModel *)self.baseModel;
        HHTableViewCell *testCell = [HHTableViewCell tableViewCellWithTableView:tableView];
        testCell.testModel = testModel;
        
        return testCell;
    }
    
    HDBaseTableViewCell *baseCell = [HDBaseTableViewCell baseTableViewCellWithTableView:tableView];
    baseCell.baseModel = self.baseModel;
    
    return baseCell;
}

- (void)tableView:(UITableView *)tableView didSelectRowAtIndexPath:(NSIndexPath *)indexPath
{
    [tableView deselectRowAtIndexPath:indexPath animated:YES];
    
    self.groupModel = self.groupsArr[indexPath.section];
    self.baseModel = self.groupModel.baseModels[indexPath.row];
    
    if (self.baseModel.option)
    {
        self.baseModel.option();
        return; 
    }
    
    if ([self.baseModel isKindOfClass:[HDCanJumpModel class]])
    {
        HDCanJumpModel *canJumpModel = (HDCanJumpModel *)self.baseModel;
        
        if (canJumpModel.controllerClass)
        {
            UIViewController *vc = [[canJumpModel.controllerClass alloc] init];
            vc.title = canJumpModel.labelText;
            [self.navigationController pushViewController:vc animated:YES];
        }
        
        return;
    }
}

- (NSString *)tableView:(UITableView *)tableView titleForHeaderInSection:(NSInteger)section
{
    self.groupModel = self.groupsArr[section];
    return self.groupModel.headerText;
}

- (NSString *)tableView:(UITableView *)tableView titleForFooterInSection:(NSInteger)section
{
    self.groupModel = self.groupsArr[section];
    return self.groupModel.footerText;
}

@end









